@@ -2,6 +2,7 @@ import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
     formatter_from_formatter_name, available_formats, int_as_string, tuple_to_csv
+from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -401,7 +402,7 @@ def show(haproxy_action_svc: HaproxyActionFacade, **kwargs):
     '--http_response_set_status_code',
     help=('Replaces the response status code. Must be an integer between 100 and 999.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -906,7 +907,7 @@ def create(haproxy_action_svc: HaproxyActionFacade, **kwargs):
     '--http_response_set_status_code',
     help=('Replaces the response status code. Must be an integer between 100 and 999.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
