@@ -2,6 +2,7 @@ import click
 from opnsense_cli.formatters.cli_output import CliOutputFormatter
 from opnsense_cli.callbacks.click import \
     formatter_from_formatter_name, bool_as_string, available_formats, int_as_string, tuple_to_csv
+from opnsense_cli.types.click_param_type.int_or_empty import INT_OR_EMPTY
 from opnsense_cli.commands.plugin.haproxy import haproxy
 from opnsense_cli.api.client import ApiClient
 from opnsense_cli.api.plugin.haproxy import Settings, Service
@@ -280,7 +281,7 @@ def show(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
         'Future requests to the domain should use only HTTPS for the specified time (in seconds): 15768000 = 6 months'
     ),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=15768000,
     required=True,
@@ -345,7 +346,7 @@ def show(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
     '--tuning_maxConnections',
     help=('Set the maximum number of concurrent connections for this public service.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -523,7 +524,7 @@ def show(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
         'Depending on the stick-table type this repesents either characters or bytes.'
     ),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None,
     required=False,
@@ -933,7 +934,7 @@ def create(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
         'Future requests to the domain should use only HTTPS for the specified time (in seconds): 15768000 = 6 months'
     ),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
@@ -990,7 +991,7 @@ def create(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
     '--tuning_maxConnections',
     help=('Set the maximum number of concurrent connections for this public service.'),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
@@ -1152,7 +1153,7 @@ def create(haproxy_frontend_svc: HaproxyFrontendFacade, **kwargs):
         'Depending on the stick-table type this repesents either characters or bytes.'
     ),
     show_default=True,
-    type=int,
+    type=INT_OR_EMPTY,
     callback=int_as_string,
     default=None
 )
